# Python wrapper for Grpcurl

This is a Python wrapper for a Command-line tool for interacting with gRPC servers. Using `grpcurl-binary-wrapper` you can install Grpcurl using Pipenv or Pip, instead of manually downloading, unzipping and installing it.

## Usage

```sh
pip install grpcurl-binary-wrapper

grpcurl --help # Now you can use terraform, after you installed it with Pipenv or Pip.
```

## License

This project is [MIT Licensed](LICENSE).
__